.. Note: This file is automatically generated by make_readme.py.
.. To make changes to this file, edit that instead of this.

TurboCtl
========

TurboCtl is a RS-232 controller for a Leybold TURBOVAC i or iX turbovacuum
pump. It was written in Python 3 and is intended for Linux operating systems.

Documentation
-------------

You can view the TurboCtl documentation `here <https://turboctl.readthedocs.io/en/latest/index.html>`__.

Author
------

TurboCtl was written by Feliks Kivelä.
The author can be contacted at firstname.lastname@aalto.fi
(with the "ä" replaced by an "a").

Copyright © 2019-2024 University of Helsinki Fusor Team.

GitHub
------

The GitHub home page of the TurboCtl project can be found
`here <https://github.com/fkivela/TurboCtl>`__.

Version
-------

This is version 1.1.1.dev3 of TurboCtl.

License
-------

TurboCtl is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see https://www.gnu.org/licenses/.
